Introduction
============

Some very common filesystem-operations, wrapped into functions with names to
be easily remembered, and adjustments for wanted default behaviours, such as:
When attempting to delete a file which doesn't exist, fail silently.

